@@ -4,20 +4,11 @@ from stretch_body.device import Device
 import threading
 import textwrap
 
-RPC_SET_WACC_CONFIG = 1
-RPC_REPLY_WACC_CONFIG = 2
-RPC_GET_WACC_STATUS = 3
-RPC_REPLY_WACC_STATUS = 4
-RPC_SET_WACC_COMMAND = 5
-RPC_REPLY_WACC_COMMAND = 6
-RPC_GET_WACC_BOARD_INFO =7
-RPC_REPLY_WACC_BOARD_INFO =8
 
-TRIGGER_BOARD_RESET = 1
 
 # ######################## WACC #################################
 
-class Wacc(Device):
+class WaccBase(Device):
     """
     API to the Stretch RE1 wrist+accelerometer (Wacc) board
     The Wacc has:
@@ -30,6 +21,16 @@ class Wacc(Device):
     ext_status_cb: Callback to handle custom status data
     ext_command_cb: Callback to handle custom command data
     """
+    RPC_SET_WACC_CONFIG = 1
+    RPC_REPLY_WACC_CONFIG = 2
+    RPC_GET_WACC_STATUS = 3
+    RPC_REPLY_WACC_STATUS = 4
+    RPC_SET_WACC_COMMAND = 5
+    RPC_REPLY_WACC_COMMAND = 6
+    RPC_GET_WACC_BOARD_INFO = 7
+    RPC_REPLY_WACC_BOARD_INFO = 8
+
+    TRIGGER_BOARD_RESET = 1
 
     def __init__(self, ext_status_cb=None, ext_command_cb=None):
         Device.__init__(self, 'wacc')
@@ -40,49 +41,25 @@ class Wacc(Device):
         self._dirty_config = True #Force push down
         self._dirty_command = False
         self._command = {'d2':0,'d3':0, 'trigger':0}
-        self.name ='hello-wacc'
         self.transport = Transport(usb='/dev/hello-wacc', logger=self.logger)
         self.status = { 'ax':0,'ay':0,'az':0,'a0':0,'d0':0,'d1':0, 'd2':0,'d3':0,'single_tap_count': 0, 'state':0, 'debug':0,
                        'timestamp': 0,
                        'transport': self.transport.status}
-        self.ts_last=None
         self.board_info = {'board_version': None, 'firmware_version': None, 'protocol_version': None}
-        self.valid_firmware_protocol = 'p0'
         self.hw_valid = False
 
     # ###########  Device Methods #############
-
     def startup(self):
         with self.lock:
-            self.hw_valid=self.transport.startup()
+            self.hw_valid = self.transport.startup()
             if self.hw_valid:
                 # Pull board info
-                self.transport.payload_out[0] = RPC_GET_WACC_BOARD_INFO
+                self.transport.payload_out[0] = self.RPC_GET_WACC_BOARD_INFO
                 self.transport.queue_rpc(1, self.rpc_board_info_reply)
                 self.transport.step(exiting=False)
-                # Check that protocol matches
-                if not(self.valid_firmware_protocol == self.board_info['protocol_version']):
-                    protocol_msg = """
-                    ----------------
-                    Firmware protocol mismatch on {0}.
-                    Protocol on board is {1}.
-                    Valid protocol is: {2}.
-                    Disabling device.
-                    Please upgrade the firmware and/or version of Stretch Body.
-                    ----------------
-                    """.format(self.name, self.board_info['protocol_version'], self.valid_firmware_protocol)
-                    self.logger.warning(textwrap.dedent(protocol_msg))
-                    self.hw_valid=False
-                    self.transport.stop()
-
-            if self.hw_valid:
-                self.push_command()
-                self.pull_status()
                 return True
             return False
 
-
-
     def stop(self):
         if not self.hw_valid:
             return
@@ -106,12 +83,14 @@ class Wacc(Device):
         self._dirty_command = True
 
     def pull_status(self,exiting=False):
+
         if not self.hw_valid:
             return
         with self.lock:
             # Queue Status RPC
-            self.transport.payload_out[0] = RPC_GET_WACC_STATUS
+            self.transport.payload_out[0] = self.RPC_GET_WACC_STATUS
             sidx = 1
+
             self.transport.queue_rpc(sidx, self.rpc_status_reply)
             self.transport.step(exiting=exiting)
 
@@ -120,13 +99,13 @@ class Wacc(Device):
             return
         with self.lock:
             if self._dirty_config:
-                self.transport.payload_out[0] = RPC_SET_WACC_CONFIG
+                self.transport.payload_out[0] = self.RPC_SET_WACC_CONFIG
                 sidx = self.pack_config(self.transport.payload_out, 1)
                 self.transport.queue_rpc2(sidx, self.rpc_config_reply)
                 self._dirty_config=False
 
             if self._dirty_command:
-                self.transport.payload_out[0] = RPC_SET_WACC_COMMAND
+                self.transport.payload_out[0] = self.RPC_SET_WACC_COMMAND
                 sidx = self.pack_command(self.transport.payload_out, 1)
                 self.transport.queue_rpc2(sidx, self.rpc_command_reply)
                 self._command['trigger'] =0
@@ -146,14 +125,14 @@ class Wacc(Device):
         print('Single Tap Count', self.status['single_tap_count'])
         print('State ', self.status['state'])
         print('Debug',self.status['debug'])
-        print('Timestamp', self.status['timestamp'])
+        print('Timestamp (s)', self.status['timestamp'])
         print('Board version:', self.board_info['board_version'])
         print('Firmware version:', self.board_info['firmware_version'])
 
     # ####################### Utility functions ####################################################
     def board_reset(self):
         with self.lock:
-            self._command['trigger']=self._command['trigger']| TRIGGER_BOARD_RESET
+            self._command['trigger']=self._command['trigger']| self.TRIGGER_BOARD_RESET
             self._dirty_command=True
 
     # ################Data Packing #####################
@@ -168,25 +147,6 @@ class Wacc(Device):
             sidx += 20
             return sidx
 
-    def unpack_status(self,s):
-        with self.lock:
-            sidx=0
-            if self.ext_status_cb is not None:
-                sidx+=self.ext_status_cb(s[sidx:])
-            self.status['ax'] = unpack_float_t(s[sidx:]);sidx+=4
-            self.status['ay'] = unpack_float_t(s[sidx:]);sidx+=4
-            self.status['az'] = unpack_float_t(s[sidx:]);sidx+=4
-            self.status['a0'] = unpack_int16_t(s[sidx:]);sidx+=2
-            self.status['d0'] = unpack_uint8_t(s[sidx:]); sidx += 1
-            self.status['d1'] = unpack_uint8_t(s[sidx:]); sidx += 1
-            self.status['d2'] = unpack_uint8_t(s[sidx:]); sidx += 1
-            self.status['d3'] = unpack_uint8_t(s[sidx:]); sidx += 1
-            self.status['single_tap_count'] = unpack_uint32_t(s[sidx:]);sidx += 4
-            self.status['state'] = unpack_uint32_t(s[sidx:]); sidx += 4
-            self.status['timestamp'] = self.timestamp.set(unpack_uint32_t(s[sidx:]));sidx += 4
-            self.status['debug'] = unpack_uint32_t(s[sidx:]);sidx += 4
-            return sidx
-
     def pack_command(self,s,sidx):
         if self.ext_command_cb is not None:  # Pack custom data first
             sidx += self.ext_command_cb(s, sidx)
@@ -214,30 +174,113 @@ class Wacc(Device):
             sidx += 4
             return sidx
 
+    def unpack_status(self,s):
+        raise NotImplementedError('This method not supported for firmware on protocol {0}.'
+            .format(self.board_info['protocol_version']))
+
     # ################Transport Callbacks #####################
     def rpc_board_info_reply(self,reply):
-        if reply[0] == RPC_REPLY_WACC_BOARD_INFO:
+        if reply[0] == self.RPC_REPLY_WACC_BOARD_INFO:
             self.unpack_board_info(reply[1:])
         else:
             self.logger.warning('Error RPC_REPLY_WACC_BOARD_INFO', reply[0])
 
     def rpc_command_reply(self,reply):
-        if reply[0] != RPC_REPLY_WACC_COMMAND:
+        if reply[0] != self.RPC_REPLY_WACC_COMMAND:
             self.logger.warning('Error RPC_REPLY_WACC_COMMAND', reply[0])
 
     def rpc_config_reply(self,reply):
-        if reply[0] != RPC_REPLY_WACC_CONFIG:
+        if reply[0] != self.RPC_REPLY_WACC_CONFIG:
             self.logger.warning('Error RPC_REPLY_WACC_CONFIG', reply[0])
 
     def rpc_status_reply(self,reply):
-        if reply[0] == RPC_REPLY_WACC_STATUS:
+        if reply[0] == self.RPC_REPLY_WACC_STATUS:
             self.unpack_status(reply[1:])
         else:
             self.logger.warning('Error RPC_REPLY_WACC_STATUS', reply[0])
 
 
 
+# ######################## Wacc PROTOCOL PO #################################
+
+class Wacc_Protocol_P0(WaccBase):
+    def unpack_status(self,s):
+        with self.lock:
+            sidx=0
+            if self.ext_status_cb is not None:
+                sidx+=self.ext_status_cb(s[sidx:])
+            self.status['ax'] = unpack_float_t(s[sidx:]);sidx+=4
+            self.status['ay'] = unpack_float_t(s[sidx:]);sidx+=4
+            self.status['az'] = unpack_float_t(s[sidx:]);sidx+=4
+
+            self.status['a0'] = unpack_int16_t(s[sidx:]);sidx+=2
+            self.status['d0'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d1'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d2'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d3'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['single_tap_count'] = unpack_uint32_t(s[sidx:]);sidx += 4
+            self.status['state'] = unpack_uint32_t(s[sidx:]); sidx += 4
+            self.status['timestamp'] = self.timestamp.set(unpack_uint32_t(s[sidx:]));sidx += 4
+            self.status['debug'] = unpack_uint32_t(s[sidx:]);sidx += 4
+            return sidx
+
+# ######################## Wacc PROTOCOL P1 #################################
+class Wacc_Protocol_P1(WaccBase):
+    def unpack_status(self,s):
+        with self.lock:
+            sidx=0
+            if self.ext_status_cb is not None:
+                sidx+=self.ext_status_cb(s[sidx:])
+            self.status['ax'] = unpack_float_t(s[sidx:]);sidx+=4
+            self.status['ay'] = unpack_float_t(s[sidx:]);sidx+=4
+            self.status['az'] = unpack_float_t(s[sidx:]);sidx+=4
+            self.status['a0'] = unpack_int16_t(s[sidx:]);sidx+=2
+            self.status['d0'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d1'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d2'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['d3'] = unpack_uint8_t(s[sidx:]); sidx += 1
+            self.status['single_tap_count'] = unpack_uint32_t(s[sidx:]);sidx += 4
+            self.status['state'] = unpack_uint32_t(s[sidx:]); sidx += 4
+            self.status['timestamp'] = self.timestamp.set(unpack_uint64_t(s[sidx:]));sidx += 8
+            self.status['debug'] = unpack_uint32_t(s[sidx:]);sidx += 4
+            return sidx
 
 
 
+# ######################## PIMU #################################
+class Wacc(WaccBase):
+    """
+    API to the Stretch RE1 Power and IMU board (Pimu)
+    """
+    def __init__(self):
+        WaccBase.__init__(self)
+        #Order in descending order so more recent protocols/methods override less recent
+        self.supported_protocols = {'p0': (Wacc_Protocol_P0,), 'p1': (Wacc_Protocol_P1,Wacc_Protocol_P0,)}
 
+    def startup(self):
+        """
+        First determine which protocol version the uC firmware is running.
+        Based on that version, replaces PimuBase class inheritance with a inheritance to a child class of PimuBase that supports that protocol
+        """
+        WaccBase.startup(self)
+        if self.hw_valid:
+            if self.board_info['protocol_version'] in self.supported_protocols:
+                Wacc.__bases__ = self.supported_protocols[self.board_info['protocol_version']]
+            else:
+                protocol_msg = """
+                ----------------
+                Firmware protocol mismatch on {0}.
+                Protocol on board is {1}.
+                Valid protocols are: {2}.
+                Disabling device.
+                Please upgrade the firmware and/or version of Stretch Body.
+                ----------------
+                """.format(self.name, self.board_info['protocol_version'], self.supported_protocols.keys())
+                self.logger.warning(textwrap.dedent(protocol_msg))
+                self.hw_valid = False
+                self.transport.stop()
+
+        if self.hw_valid:
+            self.push_command()
+            self.pull_status()
+        return self.hw_valid
